@@ -134,15 +134,17 @@ def update_config(run_id: int, team_name: str, exp_name: str, config_item_list:
 
 
 
-def send_alert(run_id: int, team_name: str, exp_name: str, alert_msg: str):
-    rsp: SendAlertResponse = get_stub().send_alert(SendAlertRequest(
-        runId=run_id,
-        teamName=team_name,
-        expName=exp_name,
-        alertMessage=alert_msg,
-    ))
-
-    return rsp.rsp_result.result == "success"
+def send_alert(run_id: int, team_name: str, exp_name: str, run_name: str, title:str, message: str, level:str):
+    data = {
+        "teamName": team_name,
+        "expName": exp_name,
+        "runName": run_name,
+        "title": title,
+        "message": message,
+        "level": level,
+    }
+    rsp = http_interface.send_alert(http_host=get_http_host(), data= data)
+    return rsp["result"] == "success"
 
 def upload_log(run_id: int, team_name: str, exp_name: str, log_step: int, item_dict: Dict[str, Union[int, str, float, bool]]) -> bool:
     item_list = []
